BEGIN TRANSACTION;
PRAGMA foreign_keys=OFF;

CREATE TABLE exploitation (id_expl text primary key, nom text, prenom text);

CREATE TABLE "rpg" (
"id_expl" TEXT,
"num_ilot" TEXT,
"commune_il" TEXT,
"forme_juri" TEXT,
"classe_age" TEXT,
"surf_decla" TEXT,
"dept_ratta" TEXT,
"surface_re" TEXT,
"gc_1" TEXT,
"sgc_1" DOUBLE,
"gc_2" TEXT,
"sgc_2" DOUBLE,
"gc_3" TEXT,
"sgc_3" DOUBLE,
"gc_4" TEXT,
"sgc_4" DOUBLE,
"gc_5" TEXT,
"sgc_5" DOUBLE,
"gc_6" TEXT,
"sgc_6" DOUBLE,
"gc_7" TEXT,
"sgc_7" DOUBLE,
"gc_8" TEXT,
"sgc_8" DOUBLE,
"gc_9" TEXT,
"sgc_9" DOUBLE,
"gc_10" TEXT,
"sgc_10" DOUBLE,
"gc_11" TEXT,
"sgc_11" DOUBLE,
"gc_12" TEXT,
"sgc_12" DOUBLE,
"complexe" TEXT,
"gid" INTEGER NOT NULL PRIMARY KEY);
SELECT AddGeometryColumn('rpg', 'geom',2154, 'MULTIPOLYGON', 'XY');

CREATE TABLE "secteur" ("id_secteur" integer PRIMARY KEY autoincrement, "id_ug" integer, "id_expl" INTEGER, "surf_secteur" DOUBLE);
SELECT AddGeometryColumn('secteur', 'geom',2154, 'MULTIPOLYGON', 'XY');

CREATE TABLE "bati" ("id_bati" INTEGER PRIMARY KEY autoincrement, "bati" TEXT, "id_expl" INTEGER);
SELECT AddGeometryColumn('bati', 'geom',2154, 'POINT', 'XY');

CREATE TABLE "ocsol" ("id_ocsol" integer PRIMARY KEY autoincrement, "id_expl" TEXT, "ocsol" TEXT not null, "surf_ocsol" DOUBLE);
SELECT AddGeometryColumn('ocsol', 'geom',2154, 'MULTIPOLYGON', 'XY');

CREATE TABLE point_attraction_valeurs (
code_point_attraction text primary key,
libelle text);
INSERT INTO "point_attraction_valeurs" VALUES('eau','Eau');
INSERT INTO "point_attraction_valeurs" VALUES('sel','Sel');
INSERT INTO "point_attraction_valeurs" VALUES ('comp', 'Compléments');

CREATE TABLE "zone_interet" ("id_zi" INTEGER PRIMARY KEY autoincrement, "id_expl" INTEGER, "nom_zi" TEXT not null, "descrp_zi" TEXT);
SELECT AddGeometryColumn('zone_interet', 'geom',2154, 'MULTIPOLYGON', 'XY');

CREATE TABLE bati_valeurs (
code_bati text primary key,
libelle text);
INSERT INTO "bati_valeurs" VALUES('au','Autre bâtiment');
INSERT INTO "bati_valeurs" VALUES('si','Siège d''exploitation');
INSERT INTO "bati_valeurs" VALUES ('be', 'Bâtiment d''élevage');
INSERT INTO "bati_valeurs" VALUES ('ab', 'Abris');

CREATE TABLE ocsol_valeurs (
code_ocsol text primary key,
libelle text);
INSERT INTO "ocsol_valeurs" VALUES('au','Autres');
INSERT INTO "ocsol_valeurs" VALUES('bo','Bois');
INSERT INTO "ocsol_valeurs" VALUES('mi','Mil''ouv');
INSERT INTO "ocsol_valeurs" VALUES('pr','Prairies');
INSERT INTO "ocsol_valeurs" VALUES('cu','Cultures');
INSERT INTO "ocsol_valeurs" VALUES('pt','Prairies temporaires');
INSERT INTO "ocsol_valeurs" VALUES('pp','Prairies permanentes');
INSERT INTO "ocsol_valeurs" VALUES('mpss','Milouv-pelouses sur sol superficiel');
INSERT INTO "ocsol_valeurs" VALUES('mpsp','Milouv-pelouses sur sol profond');
INSERT INTO "ocsol_valeurs" VALUES('mla','Milouv-landes');
INSERT INTO "ocsol_valeurs" VALUES('mzh','Milouv-zone humide');

CREATE TABLE "ug" ("id_ug" integer PRIMARY KEY autoincrement, "id_expl" TEXT, "nom_ug" TEXT not null, "surf_ug" DOUBLE);
SELECT AddGeometryColumn('ug', 'geom',2154, 'MULTIPOLYGON', 'XY');

CREATE TABLE "refends" ("id_re" INTEGER PRIMARY KEY autoincrement, "id_ug" integer, "id_expl" integer);
SELECT AddGeometryColumn ('refends', 'geom', 2154, 'MULTILINESTRING', 'XT');

CREATE TABLE "point_attraction" ("id_pa" INTEGER PRIMARY KEY autoincrement, "point_attraction" TEXT, "id_expl" INTEGER, "id_ug" INTEGER);
SELECT AddGeometryColumn('point_attraction', 'geom',2154, 'POINT', 'XY');

CREATE TRIGGER update_ocsol_exploit AFTER INSERT ON ocsol
BEGIN
UPDATE ocsol
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE ocsol.id_expl is NULL;
END;

CREATE TRIGGER update_ocsol_surf AFTER INSERT ON ocsol
BEGIN
UPDATE ocsol
SET surf_ocsol = st_area (ocsol.geom) / 10000
WHERE surf_ocsol is NULL;
END;

CREATE TRIGGER update_zi_exploit AFTER INSERT ON zone_interet
BEGIN
UPDATE zone_interet
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE zone_interet.id_expl is NULL;
END;


CREATE TRIGGER update_ug_exploit AFTER INSERT ON ug
BEGIN
UPDATE ug
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE ug.id_expl is NULL;
END;

CREATE TRIGGER update_ug_surf AFTER INSERT ON ug
BEGIN
UPDATE ug
SET surf_ug = st_area (ug.geom) / 10000
WHERE surf_ug is NULL;
END;

CREATE TRIGGER update_secteur_surf AFTER INSERT ON secteur
BEGIN
UPDATE secteur
SET surf_secteur = st_area (secteur.geom) / 10000
WHERE surf_secteur is NULL;
END;

CREATE TRIGGER update_refends_ug AFTER INSERT ON refends
BEGIN
UPDATE refends
SET id_ug = (select ug.id_ug from ug,refends as ref 
WHERE st_intersects(ref.geom,ug.geom) 
and refends.id_re = ref.id_re
and length(st_intersection(ref.geom,ug.geom))>0 order by length(st_intersection(ref.geom,ug.geom)) desc
limit 1)
WHERE refends.id_ug is NULL;
END;

CREATE TRIGGER update_refends_exploit AFTER INSERT ON refends
BEGIN
UPDATE refends
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE refends.id_expl is NULL;
END;

CREATE TRIGGER update_point_attraction_exploit AFTER INSERT ON point_attraction
BEGIN
UPDATE point_attraction
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE point_attraction.id_expl is NULL;
END;

CREATE TRIGGER update_point_attraction_ug AFTER INSERT ON point_attraction
BEGIN
UPDATE point_attraction
SET id_ug = (select ug.id_ug from ug,point_attraction as pt_attrac 
where st_intersects(pt_attrac.geom,ug.geom) 
and point_attraction.id_pa = pt_attrac.id_pa)
WHERE point_attraction.id_ug is NULL;
END;

PRAGMA foreign_keys=OFF;

CREATE TRIGGER update_secteur_exploit AFTER INSERT ON secteur
BEGIN
UPDATE secteur
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE secteur.id_expl is NULL;
END;

CREATE TRIGGER update_secteur_ug AFTER INSERT ON secteur
BEGIN
UPDATE secteur
SET id_ug = (select ug.id_ug from ug,secteur as sect 
where st_intersects(sect.geom,ug.geom) 
and secteur.id_secteur = sect.id_secteur 
and st_area(st_intersection(sect.geom,ug.geom))>0 order by st_area(st_intersection(sect.geom,ug.geom)) desc
limit 1)
WHERE secteur.id_ug is NULL;
END;

CREATE TRIGGER update_bati_exploit AFTER INSERT ON bati
BEGIN
UPDATE bati
SET id_expl = (select exploitation.id_expl from exploitation)
WHERE bati.id_expl is NULL;
END;
COMMIT;
